0.2.9 (2023-03-20)
------------------

Fixes for theme support and documentation.

* Added support for themes via settings
* New documentation section for settings
* New documentation section for themes
* Fixed a bug in the filter logic
* New installation instructions (not yet complete)
